==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/ValueBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ValueBrushScaleDescription } from "./ValueBrushScaleDescription";
/**
 * @hidden
 */
var ValueBrushScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ValueBrushScaleDescriptionMetadata, _super);
    function ValueBrushScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ValueBrushScaleDescriptionMetadata.b = function (a) {
        if (ValueBrushScaleDescriptionMetadata.a == null) {
            ValueBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ValueBrushScaleDescriptionMetadata.c(ValueBrushScaleDescriptionMetadata.a);
        }
        if (a.g(ValueBrushScaleDescriptionMetadata.a)) {
            return;
        }
        a.s(ValueBrushScaleDescriptionMetadata.a);
    };
    ValueBrushScaleDescriptionMetadata.c = function (a) {
        BrushScaleDescriptionMetadata.c(a);
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("IsLogarithmic", "Boolean");
        a.item("LogarithmBase", "Number:int");
    };
    ValueBrushScaleDescriptionMetadata.d = function (a) {
        ValueBrushScaleDescriptionMetadata.b(a);
        a.u("ValueBrushScale", function () { return new ValueBrushScaleDescription(); });
        a.t("ValueBrushScale", ValueBrushScaleDescriptionMetadata.a);
    };
    ValueBrushScaleDescriptionMetadata.$t = markType(ValueBrushScaleDescriptionMetadata, 'ValueBrushScaleDescriptionMetadata');
    ValueBrushScaleDescriptionMetadata.a = null;
    return ValueBrushScaleDescriptionMetadata;
}(Base));
export { ValueBrushScaleDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ValueBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ValueBrushScaleDescription } from "./ValueBrushScaleDescription";
/**
 * @hidden
 */
var ValueBrushScaleDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ValueBrushScaleDescriptionMetadata, _super);
    function ValueBrushScaleDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ValueBrushScaleDescriptionMetadata.b = function (a) {
        if (ValueBrushScaleDescriptionMetadata.a == null) {
            ValueBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ValueBrushScaleDescriptionMetadata.c(ValueBrushScaleDescriptionMetadata.a);
        }
        if (a.j(ValueBrushScaleDescriptionMetadata.a)) {
            return;
        }
        a.y(ValueBrushScaleDescriptionMetadata.a);
    };
    ValueBrushScaleDescriptionMetadata.c = function (a) {
        BrushScaleDescriptionMetadata.c(a);
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("IsLogarithmic", "Boolean");
        a.item("LogarithmBase", "Number:int");
    };
    ValueBrushScaleDescriptionMetadata.d = function (a) {
        ValueBrushScaleDescriptionMetadata.b(a);
        a.aa("ValueBrushScale", function () { return new ValueBrushScaleDescription(); });
        a.z("ValueBrushScale", ValueBrushScaleDescriptionMetadata.a);
    };
    ValueBrushScaleDescriptionMetadata.$t = markType(ValueBrushScaleDescriptionMetadata, 'ValueBrushScaleDescriptionMetadata');
    ValueBrushScaleDescriptionMetadata.a = null;
    return ValueBrushScaleDescriptionMetadata;
}(Base));
export { ValueBrushScaleDescriptionMetadata };
